# Inventory Builder
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/inventory-builder#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/inventory-builder#benefits)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/inventory-builder#prerequisites)
  * [Activating the Inventory Builder](https://help.sap.com/docs/leanix/ea/inventory-builder#activating-the-inventory-builder)
  * [Extracting Fact Sheets and Relations from Files](https://help.sap.com/docs/leanix/ea/inventory-builder#extracting-fact-sheets-and-relations-from-files)
  * [Creating Fact Sheets and Relations from the Inventory Builder Inbox](https://help.sap.com/docs/leanix/ea/inventory-builder#creating-fact-sheets-and-relations-from-the-inventory-builder-inbox)
  * [Individually Reviewing and Creating Fact Sheets and Relations](https://help.sap.com/docs/leanix/ea/inventory-builder#individually-reviewing-and-creating-fact-sheets-and-relations)
  * [Creating Fact Sheets and Relations for Multiple Items](https://help.sap.com/docs/leanix/ea/inventory-builder#creating-fact-sheets-and-relations-for-multiple-items)


View all
The inventory builder uses AI to analyze diagrams, images, and text-based files. It extracts fact sheets and relations to help you build your inventory faster. You can review, adjust, and create fact sheets from discovered data.
**Restriction**
The inventory builder is a premium AI feature. To use it in production workspaces, you must accept the AI terms and have AI units assigned to your tenant. In some test or demo workspaces, you may be able to try premium AI features without buying AI units.
